@@ -1,8 +1,12 @@
+# Parametric Models
 from .musyc import MuSyC
+from .zimmer import Zimmer
+from .braid import BRAID
+
+# Nonparametric models
 from .bliss import Bliss
-from .combination_index import CombinationIndex
 from .hsa import HSA
 from .loewe import Loewe
+from .combination_index import CombinationIndex
 from .schindler import Schindler
-from .zero_interaction_potency import ZIP
-from .zimmer import Zimmer
\ No newline at end of file
+from .zero_interaction_potency import ZIP
\ No newline at end of file
